%global pkg nesc
%global pkgname nesC

Name:           nesc
Version:        1.3.5
Release:        12%{?dist}
Summary:        Compiler used by TinyOS
License:        GPLv2 and (GPLv2 or BSD)
URL:            http://nescc.sourceforge.net/
Source0:        http://downloads.sourceforge.net/nescc/%{name}-%{version}.tar.gz
Source1:        nesc-mode-init.el
Patch0:         nesc-load-el-without-extension.patch
# 2014-06-09: Submitted upstream: https://github.com/tinyos/nesc/pull/30
Patch1:         nesc-1.3.2-vim-ftdetect.patch
# 2014-06-09: Submitted upstream: https://github.com/tinyos/nesc/pull/29
Patch2:         nesc-1.3.5-fix-all-incorrect-fsf-address.patch
# Fix building with -Werror=format-security, bug #1471022,
# submitted to upstream: https://github.com/tinyos/nesc/pull/40
Patch3:         nesc-1.3.6-Fix-building-with-Werror-format-security.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gettext-devel
BuildRequires:  gperf
BuildRequires:  libtool
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  perl-generators
%if 0%{?el} >= 6
BuildRequires:  puppet
%endif
Requires:       java-headless 
Requires:       jpackage-utils
Requires:       perl-interpreter
Requires:       vim-common
Provides:       bundled(libiberty)

%description
The nesC language was designed to support the TinyOS project. 
nesC provides several advantages over C: a component model based 
on bi-directional interfaces, whole-program compilation for 
performance and a simple concurrency model for embedded systems.

# EL uses old cc-mode, so don't build it

%if 0%{?fedora}
%package -n     emacs-%{pkg}
Summary:        Emacs Lisp files to run %{pkgname} under GNU Emacs
BuildArch:      noarch
BuildRequires:  emacs
Requires:       emacs(bin) >= %{_emacs_version}
Obsoletes:      emacs-%{pkg}-el <= 1.3.5-9
Provides:       emacs-%{pkg}-el = 1.3.5-10

%description -n emacs-%{pkg}
This package contains the byte-compiled Emacs Lisp packages to run %{pkgname}
with GNU Emacs.
%endif

%prep
%setup -q

%if 0%{?fedora}
%patch0 -p1 -b .emacs
%endif
%patch1 -p1 -b .fix
# This patch seems to mess with the timestamps making compilation fail
#patch2 -p1 -b .address
%patch3 -p1 -b .format

%build
autoreconf -fiv
%configure --enable-m4_pattern_allow
%make_build

%if 0%{?fedora}
%{_emacs_bytecompile} tools/editor-modes/emacs/*.el
%endif

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/vim/vimfiles/ftdetect
mkdir -p %{buildroot}%{_datadir}/vim/vimfiles/syntax

%if 0%{?fedora}
mkdir -p %{buildroot}/%{_emacs_sitelispdir}/%{pkg}
mkdir -p %{buildroot}/%{_emacs_sitestartdir}
install -pm644 tools/editor-modes/emacs/*.elc %{buildroot}%{_emacs_sitelispdir}/%{pkg} 
install -pm644 tools/editor-modes/emacs/*.el  %{buildroot}%{_emacs_sitelispdir}/%{pkg}
install -pm644 %{SOURCE1} %{buildroot}%{_emacs_sitestartdir}
%endif

# properly install vim syntax file
install -pm 644 tools/editor-modes/vim/filetype.vim %{buildroot}/%{_datadir}/vim/vimfiles/ftdetect/nesc.vim
install -pm 644 tools/editor-modes/vim/nesc.vim %{buildroot}/%{_datadir}/vim/vimfiles/syntax/nesc.vim

rm -rf %{buildroot}%{_datadir}/ncc/editor-modes/emacs
rm -rf %{buildroot}%{_datadir}/ncc/editor-modes/gedit
rm -rf %{buildroot}%{_datadir}/ncc/editor-modes/kde

%files
%{_bindir}/%{name}*
%{_libdir}/ncc/
%{_mandir}/man1/%{name}*.1*
%{_datadir}/ncc/
%{_datadir}/vim/vimfiles/ftdetect/%{pkg}.vim
%{_datadir}/vim/vimfiles/syntax/%{pkg}.vim

%if 0%{?fedora}
%files -n emacs-%{pkg}
%{_emacs_sitelispdir}/%{pkg}/*.el
%{_emacs_sitelispdir}/%{pkg}/*.elc
%{_emacs_sitestartdir}/*.el
%dir %{_emacs_sitelispdir}/%{pkg}
%doc tools/editor-modes/emacs/readme.txt
%endif

%changelog
* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.5-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.5-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Feb 06 2018 Tim Landscheidt <tim@tim-landscheidt.de> - 1.3.5-10
- Obsolete -el subpackage (#1542614)

* Mon Aug 28 2017 Petr Pisar <ppisar@redhat.com> - 1.3.5-9
- Fix building with -Werror=format-security (bug #1471022)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.5-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jul 13 2017 Petr Pisar <ppisar@redhat.com> - 1.3.5-6
- perl dependency renamed to perl-interpreter
  <https://fedoraproject.org/wiki/Changes/perl_Package_to_Install_Core_Modules>

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jun 09 2014 Till Maas <opensource@till.name> - 1.3.5-1
- Update to new upstream releases
- Submit patches upstream
- Do not hardcode manpage compression suffix
- Disable FSF address patch

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 1.3.4-7
- Use Requires: java-headless rebuild (#1067528)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1.3.4-5
- Perl 5.18 rebuild

* Sat Apr 20 2013 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.4-4
- Use autoconf

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Oct 15 2012 Jon Ciesla <limburgher@gmail.com> - 1.3.4-2
- Provides: bundled(libiberty)

* Tue Aug 14 2012 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.4-1
- Updated to 1.3.4.

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Dec 30 2011 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.3-1
- Updated to 1.3.3.
- Provide vim files for EL6.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Aug 18 2010 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.2-3
- Added patch by Till Maas for vim support for nesC.

* Sat Aug 14 2010 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.2-2
- Updated URL to use http://nescc.sourceforge.net

* Fri Aug 06 2010 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.2-1
- Updated to upstream 1.3.2 release.
- Use GPLv2 and (GPLv2 or BSD) license.
- Use optflags with configure.
- Added BR perl.
- Added if construct for building emacs only for Fedora.
- Updated to use latest Emacs packaging guidelines.

* Fri Jul 02 2010 Shakthi Kannan <shakthimaan [AT] fedoraproject DOT org> - 1.3.1-2
- Added java-devel as BR.
- Created GNU Emacs sub-package.

* Tue May 12 2009 Chitlesh Goorah <chitlesh [AT] fedoraproject DOT org> - 1.3.1-1
- Draft specification.
